summaryrefslogtreecommitdiff
path: root/tests/test_stanza_element.py
diff options
context:
space:
mode:
authorEmmanuel Gil Peyrot <linkmauve@linkmauve.fr>2014-09-21 18:51:06 +0200
committerFlorent Le Coz <louiz@louiz.org>2014-09-28 23:58:46 +0200
commit7c3e61950d902441dfb86de0cdebbc4ff38033a3 (patch)
treef714fc81382d320875ca7745f1f3d68c4ace78cf /tests/test_stanza_element.py
parent61f89eef2eac74821fae12e0389e58dc1a05a075 (diff)
downloadslixmpp-7c3e61950d902441dfb86de0cdebbc4ff38033a3.tar.gz
slixmpp-7c3e61950d902441dfb86de0cdebbc4ff38033a3.tar.bz2
slixmpp-7c3e61950d902441dfb86de0cdebbc4ff38033a3.tar.xz
slixmpp-7c3e61950d902441dfb86de0cdebbc4ff38033a3.zip
Remove all deprecated alias in the core of slixmpp, and wherever they were used.
Diffstat (limited to 'tests/test_stanza_element.py')
-rw-r--r--tests/test_stanza_element.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/tests/test_stanza_element.py b/tests/test_stanza_element.py
index 52ca87f0..eb5791fc 100644
--- a/tests/test_stanza_element.py
+++ b/tests/test_stanza_element.py
@@ -38,7 +38,7 @@ class TestElementBase(SlixTest):
""")
def testGetStanzaValues(self):
"""Test getStanzaValues using plugins and substanzas."""
class TestStanzaPlugin(ElementBase):
name = "foo2"
@@ -65,7 +65,7 @@ class TestElementBase(SlixTest):
substanza['bar'] = 'c'
stanza.append(substanza)
- values = stanza.getStanzaValues()
+ values = stanza.get_stanza_values()
expected = {'lang': '',
'bar': 'a',
'baz': '',
@@ -85,7 +85,7 @@ class TestElementBase(SlixTest):
def testSetStanzaValues(self):
"""Test using setStanzaValues with substanzas and plugins."""
class TestStanzaPlugin(ElementBase):
name = "pluginfoo"
@@ -157,10 +157,10 @@ class TestElementBase(SlixTest):
stanza = TestStanza()
substanza = TestStanza()
stanza.append(substanza)
- stanza.setStanzaValues({'bar': 'a',
- 'baz': 'b',
- 'qux': 42,
- 'foobar': {'fizz': 'c'}})
+ stanza.set_stanza_values({'bar': 'a',
+ 'baz': 'b',
+ 'qux': 42,
+ 'foobar': {'fizz': 'c'}})
# Test non-plugin interfaces
expected = {'substanzas': [substanza],
@@ -38,7 +38,7 @@ class TestElementBase(SlixTest):
""")
def testGetStanzaValues(self):
- """Test getStanzaValues using plugins and substanzas."""
+ """Test get_stanza_values using plugins and substanzas."""
class TestStanzaPlugin(ElementBase):
name = "foo2"
@@ -85,7 +85,7 @@ class TestElementBase(SlixTest):
def testSetStanzaValues(self):
- """Test using setStanzaValues with substanzas and plugins."""
+ """Test using set_stanza_values with substanzas and plugins."""
class TestStanzaPlugin(ElementBase):
name = "pluginfoo"